from setuptools import setup

setup(
    name='kylileo',
    version='0.1',
    packages=['kylileo'],
    url='https://github.com/kyllebirnie/kylileo',
    license='MIT',
    author='Kylle',
    author_email='kyllebirnie@googlemail.com',
    description='A python package test'
)
